Loanapp
├── config/
│   ├── __init__.py
│   └── config.py
├── datasets/
│   ├── loanTrain.csv
│   └── test_loan.csv
├── processing/
│   ├── __init__.py
│   ├── data_handling.py
│   └── preprocessing.py
├── trained_models/
│   └── classification.pkl
├── VERSION
├── __init__.py
├── pipeline.py
├── predict.py
├── training_pipeline.py
├── MANIFEST.in
├── README.md
├── requirements.txt
└── setup.py
